==> com.liferay.document.library.web-6.0.119-sources.jar: META-INF/resources/document_library/js/LanguageSelector.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

import ClayButton from '@clayui/button';
import ClayDropDown from '@clayui/drop-down';
import ClayIcon from '@clayui/icon';
import PropTypes from 'prop-types';
import React, {useEffect, useState} from 'react';

function getLanguage(id) {
	const text = id.replace('_', '-');
	const icon = text.toLowerCase();

	return {
		icon,
		text,
	};
}

function LanguageSelector({languageIds, onChange, selectedLanguageId}) {
	const [isDropdownOpen, setIsDropdownOpen] = useState(false);
	const selectedLanguage = getLanguage(selectedLanguageId);

	return (
		<ClayDropDown
			active={isDropdownOpen}
			onActiveChange={setIsDropdownOpen}
			trigger={
				<ClayButton displayType="secondary" monospaced>
					<span className="inline-item">
						<ClayIcon symbol={selectedLanguage.icon} />
					</span>

					<span className="btn-section">{selectedLanguage.text}</span>
				</ClayButton>
			}
		>
			<ClayDropDown.ItemList>
				{languageIds.map((id) => {
					const {icon, text} = getLanguage(id);

					return (
						<ClayDropDown.Item
							active={id === selectedLanguageId}
							key={id}
							onClick={() => {
								onChange(id);
								setIsDropdownOpen(false);
							}}
						>
							<span className="inline-item inline-item-before">
								<ClayIcon symbol={icon} />
							</span>

							{text}
						</ClayDropDown.Item>
					);
				})}
			</ClayDropDown.ItemList>
		</ClayDropDown>
	);
}

LanguageSelector.propTypes = {
	languageIds: PropTypes.arrayOf(PropTypes.string).isRequired,
	onChange: PropTypes.func.isRequired,
	selectedLanguageId: PropTypes.string.isRequired,
};

function DataEngineLanguageSelector({
	ddmStructureIds,
	portletNamespace,
	selectedLanguageId: initialSelectedLanguageId,
	translatedLanguageIds: initialTranslatedLanguageIds,
	...restProps
}) {
	const [selectedLanguageId, setSelectedLanguageId] = useState(
		initialSelectedLanguageId
	);
	const [translatedLanguageIds, setTranslatedLanguageIds] = useState([
		...new Set([
			...initialTranslatedLanguageIds,
			initialSelectedLanguageId,
		]),
	]);

	const handleLocaleChange = (localeId) => {
		setSelectedLanguageId(localeId);

		if (!translatedLanguageIds.includes(localeId)) {
			setTranslatedLanguageIds([...translatedLanguageIds, localeId]);
		}
	};

	useEffect(() => {
		ddmStructureIds.forEach((ddmStructureId) => {
			Liferay.componentReady(
				`${portletNamespace}dataEngineLayoutRenderer${ddmStructureId}`
			).then((dataEngineLayoutRenderer) => {
				const {
					reactComponentRef: {current},
				} = dataEngineLayoutRenderer;

				if (current) {
					current.updateEditingLanguageId({
						editingLanguageId: selectedLanguageId,
					});
				}
			});
		});
	}, [portletNamespace, selectedLanguageId, ddmStructureIds]);

	return (
		<>
			<input
				name={`${portletNamespace}availableLocales`}
				type="hidden"
				value={translatedLanguageIds.join(',')}
			/>

			<LanguageSelector
				{...restProps}
				onChange={handleLocaleChange}
				selectedLanguageId={selectedLanguageId}
			/>
		</>
	);
}

DataEngineLanguageSelector.propTypes = {
	ddmStructureIds: PropTypes.arrayOf(PropTypes.string).isRequired,
	portletNamespace: PropTypes.string.isRequired,
	selectedLanguageId: PropTypes.string.isRequired,
	translatedLanguageIds: PropTypes.arrayOf(PropTypes.string).isRequired,
};

export default DataEngineLanguageSelector;

==> com.liferay.document.library.web-6.0.163-sources.jar: META-INF/resources/document_library/js/LanguageSelector.js <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import ClayButton from '@clayui/button';
import ClayDropDown from '@clayui/drop-down';
import ClayIcon from '@clayui/icon';
import PropTypes from 'prop-types';
import React, {useEffect, useState} from 'react';

function getLanguage(id) {
	const text = id.replaceAll('_', '-');
	const icon = text.toLowerCase();

	return {
		icon,
		text,
	};
}

function LanguageSelector({languageIds, onChange, selectedLanguageId}) {
	const [isDropdownOpen, setIsDropdownOpen] = useState(false);
	const selectedLanguage = getLanguage(selectedLanguageId);

	return (
		<ClayDropDown
			active={isDropdownOpen}
			onActiveChange={setIsDropdownOpen}
			trigger={
				<ClayButton displayType="secondary" monospaced>
					<span className="inline-item">
						<ClayIcon symbol={selectedLanguage.icon} />
					</span>

					<span className="btn-section">{selectedLanguage.text}</span>
				</ClayButton>
			}
		>
			<ClayDropDown.ItemList>
				{languageIds.map((id) => {
					const {icon, text} = getLanguage(id);

					return (
						<ClayDropDown.Item
							active={id === selectedLanguageId}
							key={id}
							onClick={() => {
								onChange(id);
								setIsDropdownOpen(false);
							}}
						>
							<span className="inline-item inline-item-before">
								<ClayIcon symbol={icon} />
							</span>

							{text}
						</ClayDropDown.Item>
					);
				})}
			</ClayDropDown.ItemList>
		</ClayDropDown>
	);
}

LanguageSelector.propTypes = {
	languageIds: PropTypes.arrayOf(PropTypes.string).isRequired,
	onChange: PropTypes.func.isRequired,
	selectedLanguageId: PropTypes.string.isRequired,
};

function DataEngineLanguageSelector({
	ddmStructureIds,
	portletNamespace,
	selectedLanguageId: initialSelectedLanguageId,
	translatedLanguageIds: initialTranslatedLanguageIds,
	...restProps
}) {
	const [selectedLanguageId, setSelectedLanguageId] = useState(
		initialSelectedLanguageId
	);
	const [translatedLanguageIds, setTranslatedLanguageIds] = useState([
		...new Set([
			...initialTranslatedLanguageIds,
			initialSelectedLanguageId,
		]),
	]);

	const handleLocaleChange = (localeId) => {
		setSelectedLanguageId(localeId);

		if (!translatedLanguageIds.includes(localeId)) {
			setTranslatedLanguageIds([...translatedLanguageIds, localeId]);
		}
	};

	useEffect(() => {
		ddmStructureIds.forEach((ddmStructureId) => {
			Liferay.componentReady(
				`${portletNamespace}dataEngineLayoutRenderer${ddmStructureId}`
			).then((dataEngineLayoutRenderer) => {
				const {
					reactComponentRef: {current},
				} = dataEngineLayoutRenderer;

				if (current) {
					current.updateEditingLanguageId({
						editingLanguageId: selectedLanguageId,
					});
				}
			});
		});
	}, [portletNamespace, selectedLanguageId, ddmStructureIds]);

	return (
		<>
			<input
				name={`${portletNamespace}availableLocales`}
				type="hidden"
				value={translatedLanguageIds.join(',')}
			/>

			<LanguageSelector
				{...restProps}
				onChange={handleLocaleChange}
				selectedLanguageId={selectedLanguageId}
			/>
		</>
	);
}

DataEngineLanguageSelector.propTypes = {
	ddmStructureIds: PropTypes.arrayOf(PropTypes.string).isRequired,
	portletNamespace: PropTypes.string.isRequired,
	selectedLanguageId: PropTypes.string.isRequired,
	translatedLanguageIds: PropTypes.arrayOf(PropTypes.string).isRequired,
};

export default DataEngineLanguageSelector;
